clear all, clc, close all

load('reactions.mat')
load('species.mat')

% Find internal energy for each species
E_i = str2double(erase(species{2},'eV'));
% N2v1 index in species.csv
N2v1_index = find(strcmp(species{1},'N2v1'));
% N2 energy levels
% V Laporta et al Plasma Sources Sci. Technol. 23 (2014) 065002
% https://iopscience.iop.org/article/10.1088/0963-0252/23/6/065002/pdf
E_N2v = [0; E_i(N2v1_index:N2v1_index+56); 9.748];

Tg = [300 500];
% ( v + w-1 -> v-1 + w )
%% N2(v6) + N2(v9) -> N2(v5) + N2(v10) 
figure (1)

w_list1_paper_f1 = 10; 
rate_k1_paper_f1 = 4.1e-13 * 1e-6; 
w_list2_paper_f1 = 10; 
rate_k2_paper_f1 = 8.5e-13 * 1e-6; 

% ---------------------------------------------- sfHO
rate_k1_f1_sfHO = [];
w_list1_f1_sfHO = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVsfHO_Gue19(Tg(1),reactions{4}{i},E_N2v);
        if v == 6
            rate_k1_f1_sfHO = [rate_k1_f1_sfHO rateCoeff];
            w_list1_f1_sfHO = [w_list1_f1_sfHO w];
        end
    end
end

rate_k2_f1_sfHO = [];
w_list2_f1_sfHO = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVsfHO_Gue19(Tg(2),reactions{4}{i},E_N2v);
        if v == 6
            rate_k2_f1_sfHO = [rate_k2_f1_sfHO rateCoeff];
            w_list2_f1_sfHO = [w_list2_f1_sfHO w];
        end
    end
end

% ---------------------------------------------- SSH_paper1
rate_k1_f1_SSH_paper1 = [];
w_list1_f1_SSH_paper1 = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVSSH_Gue19(Tg(1),reactions{4}{i},E_N2v);
        if v == 6
            rate_k1_f1_SSH_paper1 = [rate_k1_f1_SSH_paper1 rateCoeff];
            w_list1_f1_SSH_paper1 = [w_list1_f1_SSH_paper1 w];
        end
    end
end

rate_k2_f1_SSH_paper1 = [];
w_list2_f1_SSH_paper1 = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVSSH_Gue19(Tg(2),reactions{4}{i},E_N2v);
        if v == 6
            rate_k2_f1_SSH_paper1 = [rate_k2_f1_SSH_paper1 rateCoeff];
            w_list2_f1_SSH_paper1 = [w_list2_f1_SSH_paper1 w];
        end
    end
end

% ---------------------------------------------- FHO
rate_k1_f1_FHO = [];
w_list1_f1_FHO = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVFHO_Ahn03(Tg(1),reactions{4}{i},E_N2v);
        if v == 6
            rate_k1_f1_FHO = [rate_k1_f1_FHO rateCoeff];
            w_list1_f1_FHO = [w_list1_f1_FHO w];
        end
    end
end

rate_k2_f1_FHO = [];
w_list2_f1_FHO = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVFHO_Ahn03(Tg(2),reactions{4}{i},E_N2v);
        if v == 6
            rate_k2_f1_FHO = [rate_k2_f1_FHO rateCoeff];
            w_list2_f1_FHO = [w_list2_f1_FHO w];
        end
    end
end

m1=plot(w_list1_paper_f1,rate_k1_paper_f1,'ko','MarkerSize',6)
set(m1, 'markerfacecolor', get(m1, 'color'));
hold on
plot(w_list1_f1_sfHO,rate_k1_f1_sfHO,'k-','LineWidth',2)
hold on
plot(w_list1_f1_SSH_paper1,rate_k1_f1_SSH_paper1,'k--','LineWidth',2)
hold on
plot(w_list1_f1_FHO,rate_k1_f1_FHO,'k:','LineWidth',2)
hold on

m1=plot(w_list2_paper_f1,rate_k2_paper_f1,'ro','MarkerSize',6)
set(m1, 'markerfacecolor', get(m1, 'color'));
hold on
plot(w_list2_f1_sfHO,rate_k2_f1_sfHO,'r-','LineWidth',2)
hold on
plot(w_list2_f1_SSH_paper1,rate_k2_f1_SSH_paper1,'r--','LineWidth',2)
hold on
plot(w_list2_f1_FHO,rate_k2_f1_FHO,'r:','LineWidth',2)
hold on

xlim([0 60])
xticks(0:5:60)
xlabel('N_2 vibrational level (v)')

set(gca, 'YScale', 'log')
% ylim([1e-29 1e-15])
% yticks([1e-29 1e-27 1e-25 1e-23 1e-21 1e-19 1e-17 1e-15])
ylim([1e-26 1e-16])
yticks([1e-26 1e-24 1e-22 1e-20 1e-18 1e-16])
ylabel('k_{6,5}^{v-1,v} (m^{3}/s)')

lgd4 = legend('Billing {\itet al}','sfHO','SSH','FHO','Location','Southwest')

set(gca,'FontSize',15)

text(0.15,0.93,'N_2(v=6) + N_2(v-1) \rightarrow N_2(v=5) + N_2(v) ','Units','normalized','Color',[0 0.5 0],'FontSize',12)
text(0.45,0.2,'500 K','Units','normalized','Color','r','FontSize',12)
text(0.45,0.1,'300 K','Units','normalized','Color','k','FontSize',12)

text(0.05,0.93,'(b)','Units','normalized','Color','k','FontSize',12)

set(gcf,'position',[100,100,600,450])


%% N2(v11) + N2(v19) -> N2(v10) + N2(v20) 
figure (2)

w_list1_paper_f2 = 20; 
rate_k1_paper_f2 = 6.3e-13 * 1e-6; 
w_list2_paper_f2 = 20; 
rate_k2_paper_f2 = 1.9e-12 * 1e-6; 

% ---------------------------------------------- sfHO
rate_k1_f2_sfHO = [];
w_list1_f2_sfHO = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVsfHO_Gue19(Tg(1),reactions{4}{i},E_N2v);
        if v == 11
            rate_k1_f2_sfHO = [rate_k1_f2_sfHO rateCoeff];
            w_list1_f2_sfHO = [w_list1_f2_sfHO w];
        end
    end
end

rate_k2_f2_sfHO = [];
w_list2_f2_sfHO = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVsfHO_Gue19(Tg(2),reactions{4}{i},E_N2v);
        if v == 11
            rate_k2_f2_sfHO = [rate_k2_f2_sfHO rateCoeff];
            w_list2_f2_sfHO = [w_list2_f2_sfHO w];
        end
    end
end

% ---------------------------------------------- SSH_paper1
rate_k1_f2_SSH_paper1 = [];
w_list1_f2_SSH_paper1 = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVSSH_Gue19(Tg(1),reactions{4}{i},E_N2v);
        if v == 11
            rate_k1_f2_SSH_paper1 = [rate_k1_f2_SSH_paper1 rateCoeff];
            w_list1_f2_SSH_paper1 = [w_list1_f2_SSH_paper1 w];
        end
    end
end

rate_k2_f2_SSH_paper1 = [];
w_list2_f2_SSH_paper1 = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVSSH_Gue19(Tg(2),reactions{4}{i},E_N2v);
        if v == 11
            rate_k2_f2_SSH_paper1 = [rate_k2_f2_SSH_paper1 rateCoeff];
            w_list2_f2_SSH_paper1 = [w_list2_f2_SSH_paper1 w];
        end
    end
end

% ---------------------------------------------- FHO
rate_k1_f2_FHO = [];
w_list1_f2_FHO = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVFHO_Ahn03(Tg(1),reactions{4}{i},E_N2v);
        if v == 11
            rate_k1_f2_FHO = [rate_k1_f2_FHO rateCoeff];
            w_list1_f2_FHO = [w_list1_f2_FHO w];
        end
    end
end

rate_k2_f2_FHO = [];
w_list2_f2_FHO = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VVSSH_Gue19')==1
        [rateCoeff,v,w] = N2N2VVFHO_Ahn03(Tg(2),reactions{4}{i},E_N2v);
        if v == 11
            rate_k2_f2_FHO = [rate_k2_f2_FHO rateCoeff];
            w_list2_f2_FHO = [w_list2_f2_FHO w];
        end
    end
end

m1=plot(w_list1_paper_f2,rate_k1_paper_f2,'ko','MarkerSize',6)
set(m1, 'markerfacecolor', get(m1, 'color'));
hold on
plot(w_list1_f2_sfHO,rate_k1_f2_sfHO,'k-','LineWidth',2)
hold on
plot(w_list1_f2_SSH_paper1,rate_k1_f2_SSH_paper1,'k--','LineWidth',2)
hold on
plot(w_list1_f2_FHO,rate_k1_f2_FHO,'k:','LineWidth',2)
hold on

m1=plot(w_list2_paper_f2,rate_k2_paper_f2,'ro','MarkerSize',6)
set(m1, 'markerfacecolor', get(m1, 'color'));
hold on
plot(w_list2_f2_sfHO,rate_k2_f2_sfHO,'r-','LineWidth',2)
hold on
plot(w_list2_f2_SSH_paper1,rate_k2_f2_SSH_paper1,'r--','LineWidth',2)
hold on
plot(w_list2_f2_FHO,rate_k2_f2_FHO,'r:','LineWidth',2)
hold on

xlim([0 60])
xticks(0:5:60)
xlabel('N_2 vibrational level (v)')

set(gca, 'YScale', 'log')
% ylim([1e-29 1e-15])
% yticks([1e-29 1e-27 1e-25 1e-23 1e-21 1e-19 1e-17 1e-15])
ylim([1e-26 1e-16])
yticks([1e-26 1e-24 1e-22 1e-20 1e-18 1e-16])
ylabel('k_{11,10}^{v-1,v} (m^{3}/s)')

lgd4 = legend('Billing {\itet al}','sfHO','SSH','FHO','Location','Southwest')

set(gca,'FontSize',15)

text(0.15,0.93,'N_2(v=11) + N_2(v-1) \rightarrow N_2(v=10) + N_2(v) ','Units','normalized','Color',[0 0.5 0],'FontSize',12)
text(0.45,0.2,'500 K','Units','normalized','Color','r','FontSize',12)
text(0.45,0.1,'300 K','Units','normalized','Color','k','FontSize',12)

text(0.05,0.93,'(c)','Units','normalized','Color','k','FontSize',12)

set(gcf,'position',[100,100,600,450])

% saveas(figure(1),'/home/he/Pictures/paper_2/VV_Bil1.jpg');
% saveas(figure(2),'/home/he/Pictures/paper_2/VV_Bil2.jpg');

saveas(figure(1),'2b_VV_Bil1.jpg');
exportgraphics(figure(1),'2b_VV_Bil1.pdf','BackgroundColor','none','ContentType','vector');
saveas(figure(2),'2c_VV_Bil2.jpg');
exportgraphics(figure(2),'2c_VV_Bil2.pdf','BackgroundColor','none','ContentType','vector');

%% Guerra paper expression: formula (19) in  Gue19: Plasma Sources Sci. Technol. 28 (2019) 073001
% https://iopscience.iop.org/article/10.1088/1361-6595/ab252c/pdf
function [rateCoeff,v,w] = N2N2VVsfHO_Gue19(Tg,v_w_str,E_N2v)
% Tg: gas temperature in K
% v_w_str: "v*w" number in string
% E_N2v: double array for energy values of N2v0-v58

% identify current V-V reaction by evaluating the vibrational levels ( v + w-1 -> v-1 + w )
v_w = str2num(replace(v_w_str,"*",","));
v = v_w(1);
w = v_w(2);

% Billing corrections
if max(v,w) < 10 % has to be changed to v<10 after bechmark (check paper)
    kor=39.0625-1.5625*max(v,w);
else
    kor=25.2+24.1*((max(v,w)-10)/30)^3;
end

% evaluate rate coefficient
rateCoeff=(v)*(w)*6.35e-23*Tg^(1.5)/kor;
end


%% Guerra paper expression: formula (14) in  Gue19: Plasma Sources Sci. Technol. 28 (2019) 073001
                                                  % https://iopscience.iop.org/article/10.1088/1361-6595/ab252c/pdf
function [rateCoeff,v,w] = N2N2VVSSH_Gue19(Tg,v_w_str,E_N2v)
% nitrogenMolecularVV evaluates the rate coefficient for V-V transitions between nitrogen molecules described in
% J Loureiro and C M Ferreira, J. Phys. D: Appl. Phys. 19 (1986) 17-35
% (CHANGE!!!!)
% http://dx.doi.org/10.1088/0022-3727/19/1/007

% Tg: gas temperature in K
% v_w_str: "v*w" number in string
% E_N2v: double array for energy values of N2v0-v58 ( available at Page 4:
% https://iopscience.iop.org/article/10.1088/0963-0252/23/6/065002/meta )

% local copies and definitions of different parameters used in the function
kb = 1.38064852e-23;
Lmin = 2e-11;                   % Minimum distance between N2 molecules during V-V collision (m)
M = 2*14.007*1.660539040e-27;   % Mass of N2 (Kg)
% omega = 4.443e14;               % Harmonic frequency of the oscillator N2 (rad/s)
e_eVtoJ = 1.6021766208e-19;     % e_eVtoJ     J/eV    
Planck_constant = 6.626e-34;    % Planck constant (J*s)
chi = 6.073e-3;                 % Anharmonicity of the oscillator N2

% identify current V-V reaction by evaluating the vibrational levels ( v + w-1 -> v-1 + w ) for (v<=w-1)                                                                                            
v_w = str2num(replace(v_w_str,"*",","));
v = v_w(1);
w = v_w(2);

% intermediate calculations
Y=e_eVtoJ*abs(E_N2v(v)+E_N2v(w+1)-E_N2v(v+1)-E_N2v(w))*(pi*Lmin/(Planck_constant/2/pi))*sqrt((M/2)/(2*kb*Tg));
%   Y=9.97*sqrt(1/Tg)*(v-w);
if Y<=20
    F=0.5*(3-exp(-Y/1.5))*exp(-Y/1.5);
else
    F=8*sqrt(pi/3)*Y^(7/3)*exp(-3*Y^(2/3));
end
% Billing corrections
if max(v,w) < 10 % has to be changed to v<10 after bechmark (check paper)
    kor=39.0625-1.5625*max(v,w);
else
    kor=25.2+24.1*((max(v,w)-10)/30)^3;
end

% evaluate rate coefficient
rateCoeff=(v/(1-chi*v))*(w/(1-chi*w))*(1-chi)^2*F*6.35e-23*Tg^(1.5)/kor;
rateCoeff=rateCoeff * exp((abs(E_N2v(v)+E_N2v(w+1)-E_N2v(v+1)-E_N2v(w))*e_eVtoJ)/(kb*Tg));
%   rateCoeff=(v/(1-chi*v))*(w/(1-chi*w))*F*6.354e-23*Tg^(1.5)/kor;
end

%% Ahn paper expression: formula (7) in  Ahn03: T. Ahn et al. / Chemical Physics 298 (2004) 233–240
% https://www.sciencedirect.com/science/article/pii/S0301010403006530
function [rateCoeff,v,w] = N2N2VVFHO_Ahn03(Tg,v_w_str,E_N2v)

% Tg: gas temperature in K
% v_w_str: "v*w" number in string
% E_N2v: double array for energy values of N2v0-v58

% local copies and definitions of different parameters used in the function
kb = 1.38064852e-23;
M = 2*14.007*1.660539040e-27;   % Mass of N2 (Kg)
Planck_constant = 6.626e-34;    % Planck constant (J*s)
e_eVtoJ = 1.6021766208e-19;     % e_eVtoJ     J/eV
%             % above-used constant in "str2func" version is originally as follows
%             kb = 1.38064852e-23;            % identical to Params.constants.kB
%             M = 28*1.67377e-27;
%             Planck_constant = 6.63e-34;
%             e_eVtoJ = 1.6021766208e-19;     % identical to Params.constants.e_eVtoJ

% identify current V-V reaction by evaluating the vibrational levels ( v + w-1 -> v-1 + w )
v_w = str2num(replace(v_w_str,"*",","));
v = v_w(1);
w = v_w(2);

m = (1/(1/(M) + 1/(M)));
delta_E = e_eVtoJ*(E_N2v(v)+E_N2v(w+1)-E_N2v(v+1)-E_N2v(w));
theta_p = ( (4*pi^2*(2359*100*3e8)^2*m)/(((4e10))^2*kb) );
lamda = ( (1/(3*2^0.5)) * (theta_p/Tg)^0.5  * (abs(delta_E)/((2359*100*3e8)*Planck_constant/2/pi)) );
% normalization (evaluate rate coefficient)
if Tg == 300
    k_1001 = 0.9e-20;
elseif Tg == 500
    k_1001 = 1.8e-20;
end
rateCoeff = (v) * (w)...
    * (3-exp(-2/3*lamda)) * exp(-2/3*lamda) * exp(-delta_E/(2 * kb * Tg))/2 * k_1001;

end